@@ -5,9 +5,11 @@ from subprocess import run, PIPE
 from collections import Counter
 
 from ocrd_utils import getLogger, parse_json_string_or_file, set_json_key_value_overrides
+# from collections import Counter
 from ocrd.processor.base import run_cli
 from ocrd.resolver import Resolver
-from ocrd_validators import ParameterValidator, WorkspaceValidator, ValidationReport
+from ocrd_validators import ParameterValidator, WorkspaceValidator
+from ocrd_models import ValidationReport
 
 class ProcessorTask():
 
@@ -85,6 +87,9 @@ class ProcessorTask():
         if self.parameters:
             ret += " -p '%s'" % json.dumps(self.parameters)
         return ret
+from ocrd_validators import WorkspaceValidator
+from ocrd_utils import getLogger
+from ocrd_models import ValidationReport
 
 def validate_tasks(tasks, workspace, page_id=None, overwrite=False):
     report = ValidationReport()
@@ -130,7 +135,7 @@ def run_tasks(mets, log_level, page_id, task_strs, overwrite=False):
         log.info("Start processing task '%s'", task)
 
         # execute cli
-        returncode = run_cli(
+        returncode, out, err = run_cli(
             task.executable,
             mets,
             resolver,
@@ -145,7 +150,7 @@ def run_tasks(mets, log_level, page_id, task_strs, overwrite=False):
 
         # check return code
         if returncode != 0:
-            raise Exception("%s exited with non-zero return value %s" % (task.executable, returncode))
+            raise Exception("%s exited with non-zero return value %s. STDOUT:\n%s\nSTDERR:\n%s" % (task.executable, returncode, out, err))
 
         log.info("Finished processing task '%s'", task)
 
@@ -155,4 +160,4 @@ def run_tasks(mets, log_level, page_id, task_strs, overwrite=False):
         # check output file groups are in mets
         for output_file_grp in task.output_file_grps:
             if not output_file_grp in workspace.mets.file_groups:
-                raise Exception("Invalid state: expected output file group not in mets: %s" % output_file_grp)
+                raise Exception("Invalid state: expected output file group not in mets: %s\nSTDOUT:\n%s\nSTDERR:\n%s" % (output_file_grp, out, err))
